fineTuneFunction to train the deep architecture.fineTuneDArch(darch, trainData, targetData, ..., maxEpoch = 1,
isBin = FALSE, isClass = TRUE, validData = NULL, validTargets = NULL,
testData = NULL, testTargets = NULL, stopErr = -Inf,
stopClassErr = 101, stopValidErr = -Inf, stopValidClassErr = 101)## S3 method for class 'DArch':
fineTuneDArch(darch, trainData, targetData, ...,
maxEpoch = 1, isBin = FALSE, isClass = TRUE, validData = NULL,
validTargets = NULL, testData = NULL, testTargets = NULL,
stopErr = -Inf, stopClassErr = 101, stopValidErr = -Inf,
stopValidClassErr = 101)
DArch.FALSE. If
it is true, every value over 0.5 is interpreted as 1 and
under as 0.TRUE then statistics for
classification will be determind. Default is TRUENULLNULLNULLNULL-Inf101-Inf.101 .darch with the
function saved in the attribute fineTuneFunction of
the DArch-Object. The data (trainData,
validData, testData) and belonging classes of
the data (targetData, validTargets,
testTargets) can be hand over either as matrix or as
ff-matrix (see package ff for details). The data
and classes for validation and testing are optional. If
they are provided the network will be executed with this
datasets and statistics will be calculated. This statistics
are saved in the stats attribute (see
Net). The attribue isBin indicates
whether the output data must be interpreted as binary
value. If true every value over 0.5 is interpreted as 1
otherwise as 0. Also it is possible to set stop criteria
for the training on the error (stopErr,
stopValidErr) or the correct classifications
(stopClassErr, stopValidClassErr) of the
training or validation dataset.DArch, Net,
backpropagation, rpropagation,
minimizeAutoencoder,
minimizeClassifier