saveRBMFFWeights: Saves weights and biases of a RBM network into a ffData file.
Description
Saves the weigths and the biases for the given RBM object
to the filename given through the parameter name.Usage
saveRBMFFWeights(rbm,name="saveName")## S3 method for class 'RBM':
saveRBMFFWeights(rbm, name = "saveName")
Arguments
rbm
A instance of the class RBM. name
The name for the file.
Details
The weights and biases are saved in one file with the name
given through the parameter name and the string
"-WB". See ffsave for more details.