setVisibleBiases<-: Sets the biases of the visible units for the RBM object
Description
Sets the biases of the visible units for the RBM object
Usage
setVisibleBiases(rbm) <- value# S4 method for RBM
setVisibleBiases(rbm) <- value
Arguments
rbm
A instance of the class RBM.
value
The biases of the visible units for the RBM object.